@@ -84,7 +84,7 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
             
                     
             args["X_train"]=X_train_
-            args["X_test"]=X_train_
+            args["X_test"]=X_test_
             args["url"]=None
     
             model ,  y_prob_uno_train, y_prob_uno_test    = l.modelar(**args)
@@ -122,7 +122,7 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
 
                         
         args["X_train"]=X_train[list_cls_ini]
-        args["X_test"]=X_train[list_cls_ini]
+        args["X_test"]=X_test[list_cls_ini]
         args["url"]=url
    
     model ,  y_prob_uno_train, y_prob_uno_test    = l.modelar(**args)
