@@ -157,7 +157,9 @@ def objective_with_prune(trial: Trial, fast_check=True, X=None,y=None,fn_params=
         
         bias = kpi["bias"]
         
-        if (bias>0.15):
+        if (bias>0.15 or kpi["train/score"]==0 or kpi["valid/score"]==0  or 
+            kpi["train/precision"]==0   or kpi["valid/precision"]==0   or 
+            kpi["train/recall"]==0   or kpi["valid/recall"]==0 ):
             with_bias = True
             break
         
